@@ -10,8 +10,8 @@ import warnings
 from scipy.sparse import dok_matrix, diags
 import pandas as pd
 
-from tobler.util.util import _check_crs, _nan_check, _inf_check, _check_presence_of_crs
-
+from tobler.util.util import (_check_crs, _nan_check, _inf_check,
+                              _check_presence_of_crs)
 
 def _area_tables_binning(source_df, target_df):
     """Construct area allocation and source-target correspondence tables using a spatial indexing approach
@@ -101,6 +101,7 @@ def _area_tables_binning(source_df, target_df):
             poly2Row2[i].add(j)
 
     table = dok_matrix((n1, n2), dtype=np.float32)
+
     for polyId in range(n1):
         idRows = poly2Row1[polyId]
         idCols = poly2Column1[polyId]
@@ -172,7 +173,7 @@ def _area_tables(source_df, target_df):
         if not np.isnan(row["_left"]) and not np.isnan(row["_right"]):
             s_id = int(row["_left"])
             t_id = int(row["_right"])
-            SU[s_id, index] = row["geometry"].area
+            SU[s_id, index] = row[row.geometry.name].area
             UT[index, t_id] = 1
     source_df.drop(["_left"], axis=1, inplace=True)
     target_df.drop(["_right"], axis=1, inplace=True)
@@ -250,7 +251,7 @@ def _area_interpolate_binning(
     if table is None:
         table = _area_tables_binning(source_df, target_df)
 
-    den = source_df["geometry"].area.values
+    den = source_df[source_df.geometry.name].area.values
     if allocate_total:
         den = np.asarray(table.sum(axis=1))
     den = den + (den == 0)
@@ -270,9 +271,9 @@ def _area_interpolate_binning(
             estimates = estimates.sum(axis=0)
             extensive.append(estimates.tolist()[0])
 
-    extensive = np.asarray(extensive)
-    extensive = np.array(extensive)
-    extensive = pd.DataFrame(extensive.T, columns=extensive_variables)
+        extensive = np.asarray(extensive)
+        extensive = np.array(extensive)
+        extensive = pd.DataFrame(extensive.T, columns=extensive_variables)
 
     area = np.asarray(table.sum(axis=0))
     den = 1.0 / (area + (area == 0))
@@ -292,8 +293,8 @@ def _area_interpolate_binning(
             estimates = estimates.dot(weights).sum(axis=0)
             intensive.append(estimates.tolist()[0])
 
-    intensive = np.asarray(intensive)
-    intensive = pd.DataFrame(intensive.T, columns=intensive_variables)
+        intensive = np.asarray(intensive)
+        intensive = pd.DataFrame(intensive.T, columns=intensive_variables)
 
     if extensive_variables:
         dfs.append(extensive)
@@ -301,7 +302,7 @@ def _area_interpolate_binning(
         dfs.append(intensive)
 
     df = pd.concat(dfs, axis=1)
-    df["geometry"] = target_df["geometry"].reset_index(drop=True)
+    df["geometry"] = target_df[target_df.geometry.name].reset_index(drop=True)
     df = gpd.GeoDataFrame(df.replace(np.inf, np.nan))
     return df
 
@@ -387,7 +388,7 @@ def _area_interpolate(
         SU, UT = _area_tables(source_df, target_df)
     else:
         SU, UT = tables
-    den = source_df["geometry"].area.values
+    den = source_df[source_df.geometry.name].area.values
     if allocate_total:
         den = SU.sum(axis=1)
     den = den + (den == 0)
@@ -403,8 +404,8 @@ def _area_interpolate(
             estimates = np.dot(estimates, UT)
             estimates = estimates.sum(axis=0)
             extensive.append(estimates)
-    extensive = np.array(extensive)
-    extensive = pd.DataFrame(extensive.T, columns=extensive_variables)
+        extensive = np.array(extensive)
+        extensive = pd.DataFrame(extensive.T, columns=extensive_variables)
 
     ST = np.dot(SU, UT)
     area = ST.sum(axis=0)
@@ -418,8 +419,8 @@ def _area_interpolate(
             vals.shape = (len(vals), 1)
             est = (vals * weights).sum(axis=0)
             intensive.append(est)
-    intensive = np.array(intensive)
-    intensive = pd.DataFrame(intensive.T, columns=intensive_variables)
+        intensive = np.array(intensive)
+        intensive = pd.DataFrame(intensive.T, columns=intensive_variables)
 
     if extensive_variables:
         dfs.append(extensive)
@@ -427,7 +428,7 @@ def _area_interpolate(
         dfs.append(intensive)
 
     df = pd.concat(dfs, axis=1)
-    df["geometry"] = target_df["geometry"].reset_index(drop=True)
+    df["geometry"] = target_df[target_df.geometry.name].reset_index(drop=True)
     df = gpd.GeoDataFrame(df.replace(np.inf, np.nan))
     return df
 
@@ -440,9 +441,9 @@ def _area_tables_raster(
 
     Parameters
     ----------
-    source_df : geopandas.GeoDataFrame 
+    source_df : geopandas.GeoDataFrame
         geeodataframe with geometry column of polygon type
-    target_df : geopandas.GeoDataFrame 
+    target_df : geopandas.GeoDataFrame
         geodataframe with geometry column of polygon type
     raster_path : str
         the path to the associated raster image.
